@@ -38,7 +38,7 @@ import sys
 
 import easybuild.tools.environment as env
 import easybuild.tools.toolchain as toolchain
-from easybuild.easyblocks.netcdf import set_netcdf_env_vars, get_netcdf_module_set_cmds  #@UnresolvedImport
+from easybuild.easyblocks.netcdf import set_netcdf_env_vars, get_netcdf_module_set_cmds  # @UnresolvedImport
 from easybuild.framework.easyblock import EasyBlock
 from easybuild.framework.easyconfig import CUSTOM, MANDATORY
 from easybuild.tools.filetools import patch_perl_script_autoflush, run_cmd, run_cmd_qa
@@ -56,6 +56,8 @@ class EB_WRF(EasyBlock):
         self.wrfsubdir = None
         self.comp_fam = None
 
+        self.netcdf_mod_cmds = None
+
     @staticmethod
     def extra_options():
         extra_vars = [
@@ -75,6 +77,7 @@ class EB_WRF(EasyBlock):
 
         # netCDF dependency
         set_netcdf_env_vars(self.log)
+        self.netcdf_mod_cmds = get_netcdf_module_set_cmds(self.log)
 
         # HDF5 (optional) dependency
         hdf5 = get_software_root('HDF5')
@@ -365,6 +368,7 @@ class EB_WRF(EasyBlock):
     def make_module_extra(self):
 
         txt = super(EB_WRF, self).make_module_extra()
-        txt += get_netcdf_module_set_cmds(self.log)
+
+        txt += self.netcdf_mod_cmds
 
         return txt
